' TYPE                  Automation
' DESCRIPTION           Send an email using the CDO
' AUTHOR                Derived from examples at http://www.paulsadowski.com/WSH/cdo.htm
' REVISIONS             Started 11 September 2007
                        
' REQUIREMENTS          'Windows XP or 2000 with CDO, may also work with Vista, but Vista is 
'                       apparently missing an SMTP server and will need CDO or other installed.


Option Explicit ' Must declare all variables before using them
Const cdoSendUsingPickup    = 1 'Send message using the local SMTP service pickup directory.
Const cdoSendUsingPort      = 2 'Send the message using the network (SMTP over the network).
Const cdoAnonymous          = 0 'Do not authenticate
Const cdoBasic              = 1 'basic (clear-text) authentication
Const cdoNTLM               = 2 'NTLM

Dim objMessage          ' the CDO message object
Dim strEmailTo          ' email address to send the email to
Dim strEmailCc          ' email address to cc the email to
Dim strEmailFrom        ' email address to send the email from (return address)
Dim strNameFrom         ' Name to appear in the "From" field
Dim strAttachPath       ' Path to files to attach to the email
Dim strAttach(2)        ' Name of attachments (file names)
Dim strUserName         ' Username 
Dim strPassword         ' Password
Dim strAttachRef(2)     ' Reference name of attachments (must be reflected in HTML in strBodyFile)
Dim strSubject          ' Subject of the email"
Dim strBodyPath         ' Path to file containing the body of the message    
Dim strBodyFile         ' File name of the file to use for the body of the message
Dim strMailServer       ' Name or IP of Remote SMTP Server
Dim strLong             ' Long string
Dim i                   ' Integer for counting loops etc.


'==========================================================
'Initialisation
'==========================================================
' email address to send the email to
strEmailTo      = "name@domain.com"

' email address to cc the email to
strEmailCc      = ""

' email address to send the email from (return address)          
strEmailFrom    = "name@domain.com"

' Name to appear in the "From" field       
strNameFrom     = "Remote dScope"

'Username for strMailServer
strUserName     = "user"

'Password for username above
strPassword     = "password"

' Path to files to attach to the email
strAttachPath   = "c:/temp/"

' Name of attachments (file names)
strAttach(1)    = "graph1.png"
strAttach(2)    = "graph2.png"
      
' Reference name of attachments (must be reflected in HTML in strBodyFile) if embedding graphics
strAttachRef(1) = "trace1.png"
strAttachRef(2) = "trace2.png"

' Subject line of the email
strSubject      = "Test email from script"

' Path to file containing the body of the message 
strBodyPath     =  "C:/temp/"

' File name of the file to use for the body of the message
strBodyFile     = "results_file.html"

'Name or IP of Remote SMTP Server
strMailServer   = "mail.domain.com"


'==========================================================
'End of Initialisation
'==========================================================
If strPassword = "" then
    strPassword = InputBox("Please enter the password for username " & strUserName, "Emailing From Script")
End if

Set objMessage = CreateObject("CDO.Message")

'Set up the message
With objMessage

    .Subject = strSubject
    .From = "" & strNameFrom & " <" & strEmailFrom & ">"
    .To = strEmailto
    .Cc = strEmailCc

    'Attach files for embedding, such as graphics etc.
    .AddRelatedBodyPart strAttachPath & strAttach(1), strAttachRef(1), 1 
    .AddRelatedBodyPart strAttachPath & strAttach(2), strAttachRef(2), 1 

    'For sending a text message:
    '.TextBody = "Enter the text to send here"

    'For sending an HTML message from file
    .CreateMHTMLBody "file://" & strBodyPath & strBodyFile
    
End With    
    
'Set up the server
With objMessage.Configuration.Fields  
    'This section provides the configuration information for the remote SMTP server.

    'How to send the email 
    .Item ("http://schemas.microsoft.com/cdo/configuration/sendusing") = cdoSendUsingPort
    
    'Name or IP of Remote SMTP Server
    .Item ("http://schemas.microsoft.com/cdo/configuration/smtpserver") = strMailServer
    
    'Type of authentication, NONE, Basic (Base64 encoded), NTLM
    .Item ("http://schemas.microsoft.com/cdo/configuration/smtpauthenticate") = cdoBasic 'cdoAnonymous
    
    'Your UserID on the SMTP server
    .Item ("http://schemas.microsoft.com/cdo/configuration/sendusername") = strUserName
    
    'Your password on the SMTP server
    .Item ("http://schemas.microsoft.com/cdo/configuration/sendpassword") = strPassword
    
    'Server port (typically 25)
    .Item ("http://schemas.microsoft.com/cdo/configuration/smtpserverport") = 25
    
    'Use SSL for the connection (False or True)
    .Item ("http://schemas.microsoft.com/cdo/configuration/smtpusessl") = False
    
    'Connection Timeout in seconds (the maximum time CDO will try to establish a connection to the SMTP server)
    .Item ("http://schemas.microsoft.com/cdo/configuration/smtpconnectiontimeout") = 60
    
    .Update
    
End With  'End remote SMTP server configuration section

'send the email    
On error resume next
objMessage.Send


'Status message depending on whether or not the send email succeeded
If Not Err.Number = 0 then
    strLong = "Email Send Failure:" & vbcrlf & vbcrlf _
    & "The email failed to send with error: " & Err.Number & "  " & _
    Err.description & vbcrlf & vbcrlf & "Details:" & vbcrlf & _
    "To: " & strEmailTo & vbcrlf & _
    "cc: " & strEmailCc & vbcrlf & _
    "From: " & strEmailFrom & vbcrlf & _
    "From (Name): " & strNameFrom & vbcrlf & _
    "Subject: " & strSubject & vbcrlf & _
    "Mail Server: " & strMailServer & vbcrlf & _
    "User Name: " & strUserName & vbcrlf & "Password: "
    For i = 1 to Len(strPassword)
        strlong = strlong & "*"
    Next
    strlong = strlong & vbcrlf & "Attachment Path : " & strAttachPath & vbcrlf & _
    "HTML Path: " & strBodyPath & vbcrlf & _
    "HTML File: " & strBodyFile & vbcrlf
    msgbox strLong, vbexclamation, "Emailing from Script"
Else
    msgbox "Email successfully sent to " & strEmailTo, vbinformation, "Emailing from Script"
End If
